@@ -4,7 +4,7 @@ package App::SeismicUnixGui::configs::big_streams::iTopMute_config;
 
 =head2 SYNOPSIS 
 
- PERL PACKAGE NAME: iTop_Mute_config.pm 
+ PERL PERL PROGRAM NAME: iTop_Mute_config.pm 
  AUTHOR: Juan Lorenzo
  DATE: July 27 2016 
  DESCRIPTION Combines configuration variables
