@@ -4,7 +4,7 @@ package App::SeismicUnixGui::configs::big_streams::immodpg_config;
 
 =head2 SYNOPSIS 
 
- PERL PACKAGE NAME: immodpg_config.pm 
+ PERL PERL PROGRAM NAME: immodpg_config.pm 
  AUTHOR: Juan Lorenzo
  DATE: Feb 24 2020
  DESCRIPTION: interactive raytraced modeling
@@ -47,7 +47,7 @@ layer		= 1
 =cut 
 
 use Moose;
-my $VERSION = '0.0.1';
+our $VERSION = '0.0.1';
 use aliased 'App::SeismicUnixGui::misc::L_SU_global_constants';
 use aliased 'App::SeismicUnixGui::configs::big_streams::Project_config';
 use App::SeismicUnixGui::misc::SeismicUnix qw($in $out $on $go $to $suffix_ascii $off $suffix_su);
