@@ -2,24 +2,26 @@
          implicit none
 !       read a configuration file
 
-      integer :: result
+      real*4      :: result
       character (len=255) :: inbound, inbound_locked
       character (len=30) :: format1
-      integer :: err_message, ready
-
+      integer :: err_msg, ready
+      
       inbound_locked=trim(inbound)//"_locked"
-      format1= "(F7.1)"
+      format1=  "(F7.1)"
 
 !      print *, 'readVbot_file.f, inbound is:', trim(inbound)
 !      in case inbound is of a different, but shorter length in main
 !      create a temporary, new, lock file
+
 10     open(status='new',unit=30,file=inbound_locked,iostat=ready)
 
        if (ready.eq.0) then
-         open(unit=29,file=trim(inbound),status='old',
-     +    iostat=err_message)
+      open(unit=29,file=trim(inbound),status='old',iostat=err_msg)
+ !    +   iostat=err_msgr)
+     
  !       check whether file opens data file
-         if (err_message.eq.0) then
+         if (err_msg.eq.0) then
 
           read (29,format1) result
 !          print *, 'readVbot_file.f, result',result
@@ -33,10 +35,10 @@
          end if
 
 !       remove lock file
-11      close (status='delete',unit=30,iostat=err_message)
-        if (err_message.ne.0) then
+11      close (status='delete',unit=30,iostat=err_msg)
+        if (err_msg.ne.0) then
          go to 11
-         print *, 'readVbot_file.f, err_messg=',err_message
+         print *, 'readVbot_file.f, err_messg=',err_msg
         end if
 
        end if
