@@ -39,7 +39,7 @@ my $psimage_spec = {
 	_has_infile            => $true,
 	_has_outpar            => $false,
 	_has_pipe_in           => $true,
-	_has_pipe_out          => $true,
+	_has_pipe_out          => $false,
 	_has_redirect_in       => $true,
 	_has_redirect_out      => $true,
 	_has_subin_in          => $false,
@@ -47,7 +47,7 @@ my $psimage_spec = {
 	_is_data               => $false,
 	_is_first_of_2         => $true,
 	_is_first_of_3or_more  => $true,
-	_is_first_of_4or_more  => $true,
+	_is_first_of_4or_more  => $false,
 	_is_last_of_2          => $false,
 	_is_last_of_3or_more   => $false,
 	_is_last_of_4or_more   => $false,
