@@ -4,7 +4,7 @@ package App::SeismicUnixGui::sunix::NMO_Vel_Stk::sureduce;
 
 PERL PROGRAM NAME: 
 
-AUTHOR:  
+AUTHOR: Juan Lorenzo (Perl module only)
 
 DATE:
 
