@@ -2,9 +2,9 @@ package App::SeismicUnixGui::sunix::plot::supsgraph;
 
 =head2 SYNOPSIS
 
-PACKAGE NAME: 
+PERL PROGRAM NAME: 
 
-AUTHOR:  
+AUTHOR: Juan Lorenzo (Perl module only)
 
 DATE:
 
