@@ -5,7 +5,7 @@ package App::SeismicUnixGui::sunix::plot::suxmovie;
 =head2 SYNOPSIS
 
 PERL PROGRAM NAME:  SUXMOVIE - X MOVIE plot of a 2D or 3D segy data set 			
-AUTHOR: Juan Lorenzo
+AUTHOR: Juan Lorenzo (Perl module only)
 DATE:   
 DESCRIPTION:
 Version: 
@@ -64,7 +64,7 @@ Version:
  See the xmovie selfdoc for the remaining parameters and X functions.
 
 PERL PROGRAM NAME:  XMOVIE - image one or more frames of a uniformly sampled function f(x1,x2)
-AUTHOR: Juan Lorenzo
+AUTHOR: Juan Lorenzo (Perl module only)
 DATE:   
 DESCRIPTION:
 Version: 
