@@ -1,13 +1,14 @@
 package App::SeismicUnixGui::sunix::shell::cp;
 
 use Moose;
+our $VERSION = '0.0.1';
 
 =head1 DOCUMENTATION
 
 =head2 SYNOPSIS 
 
  PROGRAM NAME: cp
- AUTHOR: Juan Lorenzo
+AUTHOR: Juan Lorenzo (Perl module only)
  DATE: Sept. 24 2015 
  DESCRIPTION copy files
  Version 1
